import { Box, Flex, Icon, Link, Text, chakra } from "@chakra-ui/react";
import IconBoxCard from "./icon-box-card";
import { Swiper, SwiperSlide } from "swiper/react";
import { Navigation } from "swiper/modules";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import "swiper/css/scrollbar";
import { BsArrowLeftCircle, BsArrowRightCircle } from "react-icons/bs";
const SwiperChakra = chakra(Swiper);
import { motion } from "framer-motion";
import Transition from "@/utils/transition-helper";

export default function CustomSwiper() {
  const transition = Transition({offscreen:{ x:0, y: 100 }}, {onscreen: { x:0, y:0, transition: { type:"linear", duration: 1.0 }}});

  const items = [
    {
      title: "Word to PDF",
      description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
    },
    {
      title: "Word to PDF",
      description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
    },
    {
      title: "Word to PDF",
      description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
    },
    {
      title: "Word to PDF",
      description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
    },
    {
      title: "Word to PDF",
      description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
    },
  ];

  return (
    <Box pos={"relative"} w="100%" mb={16} as={motion.div} initial="offscreen" whileInView="onscreen" viewport={{ once: true, amount: 0.1 }} variants={transition}>
      <Box w="80%" mx="auto" mt={16}>
        <CustomHeader />
        <SwiperChakra
          modules={[Navigation]}
          grabCursor={true}
          navigation={{ prevEl: ".swiper-custom-button-prev", nextEl: ".swiper-custom-button-next" }}
          spaceBetween={16}
          slidesPerView="auto"
          breakpoints={{
            320: { slidesPerView: 1, slidesPerGroup: 1 },
            768: { slidesPerView: 3, slidesPerGroup: 3 },
            1024: { slidesPerView: 4, slidesPerGroup: 4 },
          }}>
          {items.map((item, index) => (
            <SwiperSlide key={index}>
              <IconBoxCard item={item} />
            </SwiperSlide>
          ))}
        </SwiperChakra>
      </Box>
      <CustomArrow direction="prev" onClick={() => {}} />
      <CustomArrow direction="next" onClick={() => {}} />
    </Box>
  );
}

const CustomArrow = ({ direction, onClick }: { direction: string; onClick: () => void }) => {
  const boxStyleProps = direction == "prev" ? { left: { base: 0, md: 45, lg: 85 } } : { right: { base: 5, md: 45, lg: 85 } };

  return (
    <Box position="absolute" className={"swiper-custom-button-" + direction} top="50%" transform="translateY(-50%)" cursor="pointer" onClick={onClick} px={2} {...boxStyleProps}>
      <Icon as={direction === "prev" ? BsArrowLeftCircle : BsArrowRightCircle} boxSize={6} color="codGray.500" />
    </Box>
  );
};

const CustomHeader = () => {
  return (
    <Flex justify="space-between" align="center" mb={4}>
      <Box>
        <Text fontSize="lg" fontWeight="bold">
          Featured Items
        </Text>
      </Box>
      <Link href="/view-all" textDecoration="underline" color="codGray.500">
        View All
      </Link>
    </Flex>
  );
};
